package errpy

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file parser.ml

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
(*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *)

(** [parse_module input] takes the string [input] and parse it as a Python module, represented by a
    list of {!type: Ast.mod_}.

    In the future we can add support for type comments here *)
external parse_module
  :  string ->
  (Ast.mod_ * Ast.recoverableerrorwithlocation list, string) result
  = "parse_module"